@@ -1,6 +1,6 @@
 #ifndef __corFunctions_common_h__
 #define __corFunctions_common_h__
 
-double quantile(double * x, const size_t n, const double q, int * err);
+double quantile(double * x, const size_t n, const double q);
 
 #endif
